﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinSchedule;
using Infragistics.Win.UltraWinSchedule.TimelineView;
using Infragistics.Win;

namespace UltraTimeLineViewAppoitment
{
    public partial class Form1 : Form, Infragistics.Win.IUIElementDrawFilter
    {
        private DataTable theAppointments;
        private const int randomSeed = 0;
        private Random rnd;

        public Form1()
        {
            InitializeComponent();
            ultraTimelineView1.DrawFilter = this;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Dta_Appointments = CreateAppointmentsDataTable();
            //CreateAppointments(Dta_Appointments);


            DataSet ds = new DataSet();

            // Create Appointments DataTable
            theAppointments = new DataTable("Appointments");
            theAppointments.Columns.Add("AppointmentID", typeof(int));
            theAppointments.Columns.Add("StartTime", typeof(DateTime));
            theAppointments.Columns.Add("EndTime", typeof(DateTime));
            theAppointments.Columns.Add("Subject", typeof(string));
            theAppointments.Columns.Add("OwnerKey", typeof(string));

            // Add Appointments Sample Data

            theAppointments.Rows.Add(new object[] { 1, DateTime.Now, DateTime.Now.AddHours(1), "Test 1", "Owner 1" });
            theAppointments.Rows.Add(new object[] { 1, DateTime.Now.AddHours(1), DateTime.Now.AddHours(4), "Test 2", "Owner 2" });
            theAppointments.Rows.Add(new object[] { 1, DateTime.Now.AddHours(2), DateTime.Now.AddHours(5), "Test 3", "Owner 1" });
            theAppointments.Rows.Add(new object[] { 1, DateTime.Now.AddHours(3), DateTime.Now.AddHours(7), "Test 4", "Owner 2" });
            


            // Create Owners DataTable
            DataTable theOwners = new DataTable("Owners");
            theOwners.Columns.Add("OwnerID", typeof(int));
            theOwners.Columns.Add("Name", typeof(string));
            theOwners.Columns.Add("OwnerKey", typeof(string));

            // Add Owners Sample Data
            theOwners.Rows.Add(new object[] { 1, "Owner 1", "Owner 1" });
            theOwners.Rows.Add(new object[] { 2, "Owner 2", "Owner 2" });


            ds.Tables.Add(theAppointments);
            ds.Tables.Add(theOwners);


            this.ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;
            this.ultraCalendarInfo1.DataBindingsForAppointments.DataSource = ds.Tables["Appointments"];
            this.ultraCalendarInfo1.DataBindingsForOwners.DataSource = ds.Tables["Owners"];

            // Set Appointments data binding properties to UltraCalendarInfo
            this.ultraCalendarInfo1.DataBindingsForAppointments.StartDateTimeMember = "StartTime";

            this.ultraCalendarInfo1.DataBindingsForAppointments.EndDateTimeMember = "EndTime";

            this.ultraCalendarInfo1.DataBindingsForAppointments.SubjectMember = "Subject";
            this.ultraCalendarInfo1.DataBindingsForAppointments.OwnerKeyMember = "OwnerKey";

            // Set Owners data binding properties to UltraCalendarInfo
            this.ultraCalendarInfo1.DataBindingsForOwners.KeyMember = "OwnerKey";
            this.ultraCalendarInfo1.DataBindingsForOwners.NameMember = "Name";

            // Assign CalendarInfo component to TimelineView control
            ultraTimelineView1.CalendarInfo = this.ultraCalendarInfo1;
        }

        private DataTable CreateAppointmentsDataTable()
        {
            DataTable newTable = new DataTable();

            //Basic Appointment properties
            //In order to function properly, the table must contain data for 
            //Subject, StartDateTime, and EndDateTime. These three fields are 
            //required for an appointment. So all of these will have DefaultValues.
            newTable.Columns.Add("Subject", typeof(string));
            newTable.Columns["Subject"].DefaultValue = "New Appointment";
            newTable.Columns.Add("StartDateTime", typeof(DateTime));
            newTable.Columns["StartDateTime"].DefaultValue = DateTime.Now;
            newTable.Columns.Add("EndDateTime", typeof(DateTime));
            newTable.Columns["EndDateTime"].DefaultValue = DateTime.Now.AddHours(1);
            newTable.Columns.Add("Description", typeof(String));

            // All other fields are Optional.

            //Properties for AllDayEvents
            newTable.Columns.Add("AllDayEvent", typeof(Boolean));
            newTable.Columns["AllDayEvent"].DefaultValue = false;

            //Properties for Reminders
            newTable.Columns.Add("ReminderEnabled", typeof(bool));
            newTable.Columns["ReminderEnabled"].DefaultValue = false;
            newTable.Columns.Add("ReminderInterval", typeof(int));
            newTable.Columns.Add("ReminderUnits", typeof(int));

            //Properties when using owners
            newTable.Columns.Add("OwnerKey", typeof(string));

            //Properties when using recurring appointments. 
            newTable.Columns.Add("RecurrenceId", typeof(System.Guid));
            newTable.Columns.Add("Recurrence", typeof(Byte[]));
            newTable.Columns.Add("OriginalStartDateTime", typeof(DateTime));

            //DataKey is an extra field that can be used to link the appointment to some external data. 
            newTable.Columns.Add("DataKey", typeof(string));

            //All properties    
            //Any other Appointment properties not covered above are stored as 
            //Binary data in the AllProperties field. This includes properties like 
            //BarColor, Location, etc. 
            newTable.Columns.Add("AllProperties", typeof(Byte[]));
            return newTable;


        }

        public bool DrawElement(Infragistics.Win.DrawPhase drawPhase, ref Infragistics.Win.UIElementDrawParams drawParams)
        {

            // to compare with default functionality 
            //return false;
            if (drawParams.Element is AppointmentUIElement)
            {
                AppointmentDisplaySettings displaySettings = ultraTimelineView1.AppointmentDisplaySettings;
                Rectangle rect = drawParams.Element.Rect;
                Rectangle rectInsideBorders = drawParams.Element.RectInsideBorders;
                int borderHeight = rectInsideBorders.Top - rect.Top;
                
                int barColorHeight =  displaySettings.BarColorIndicatorHeightResolved;
                barColorHeight += borderHeight;
                rect.Height =  barColorHeight;

                if (ultraTimelineView1.AlignActivityWithPrimaryIntervalResolved)
                {
                    if (((AppointmentUIElement)drawParams.Element).StartTimeVisible)
                    {
                        int DayDuration = ultraTimelineView1.CalendarInfo.LogicalDayDuration.Hours;
                        int StartHour = ultraTimelineView1.CalendarInfo.LogicalDayOffset.Hours;
                        int EndHour = StartHour + DayDuration;

                        int HourPerWidth = ((AppointmentUIElement)drawParams.Element).Rect.Width / DayDuration;

                        if (((AppointmentUIElement)drawParams.Element).Start.Hour > StartHour)
                        {
                            int StartHourDiff = ((AppointmentUIElement)drawParams.Element).Start.Hour - StartHour;
                            rect.X = HourPerWidth * StartHourDiff;

                            int Duratation = ((AppointmentUIElement)drawParams.Element).End.Hour - ((AppointmentUIElement)drawParams.Element).Start.Hour;
                            rect.Width  = HourPerWidth * Duratation;
                        }
                    }
                    displaySettings.BarColorIndicatorVisibility = TimelineViewBarColorIndicatorVisibility.Hide;
                }

                using (SolidBrush brush = new SolidBrush(Color.Red))
                {
                    drawParams.Graphics.FillRectangle(brush, rect);
                }
            }
            return false;

        }
        public Infragistics.Win.DrawPhase GetPhasesToFilter(ref Infragistics.Win.UIElementDrawParams drawParams)
        {
            if (drawParams.Element is AppointmentUIElement) return DrawPhase.AfterDrawBackColor;
            else return DrawPhase.None;
        }
    }


}



